==> as-is-1.6.0.tgz: package/deleteme.js <==
import { Checker, BaseInterface, MicroTest, Utility } from './index.js';
import { NumbersValidator } from '@pro-script/as-is-plugins/numbers';
import { StringsValidator } from '@pro-script/as-is-plugins/strings';
const checker = new Checker({
    'IF/ELSE/END': true,
    strict: true,
    Enum: true,
    utility: true,
    integrate: Object.assign(NumbersValidator, StringsValidator)
});
const { multi, Interface, Type, as, is, IF, ELSE, END, optional, get, macro, strict, Enum } = checker;
// checker.disabled = true;
const { START, STOP, FINISH, METHOD, PROPERTY, IS, CHECK, passed, failed } = new MicroTest({ is, as });
const roles = Enum.roles({
    admin: 0,
    user: 1
});
console.log(as.Enum(roles))

const fakeEnum = Enum.new({
    name: 'admin',
    value: 0
});
console.log('is.Enum', is.Enum(fakeEnum));


const { IUser } = Type({
    IUser: {
        name: as.string,
        email: as.email,
        password: as.password,
        avatar: (value)=> {
            as.url(value);
            as.minStr({arg: value, value: 3});
            as.maxStr({arg: value, value: 40});
            return value;
        },
        role: (value) => {
            is.false(value!=='admin') && console.error('ROLE ERROR: only one admin required');
            as.roles(value);
            return value;
        }
    }
});

const result = as.IUser({
    name: 'name',
    email: 'name@domain.com',
    password: 'qweqweqweqwe',
    avatar: 'https://translate.google.com/',
    role: 'admin'
});
console.log(result);

==> as-is-1.6.2.tgz: package/deleteme.js <==
import { Checker, BaseInterface, MicroTest, Utility } from './index.js';
import { NumbersValidator } from '@pro-script/as-is-plugins/numbers';
import { StringsValidator } from '@pro-script/as-is-plugins/strings';
const checker = new Checker({
    'IF/ELSE/END': true,
    strict: true,
    Enum: true,
    utility: true,
    integrate: Object.assign(NumbersValidator, StringsValidator)
});
const { multi, Interface, Type, as, is, IF, ELSE, END, optional, get, macro, strict, Enum } = checker;
checker.disabled = true;
const { START, STOP, FINISH, METHOD, PROPERTY, IS, CHECK, passed, failed } = new MicroTest({ is, as });
const roles = Enum.roles({
    admin: 0,
    user: 1
});
console.log(as.Enum(roles))

const fakeEnum = Enum.new({
    name: 'admin',
    value: 0
});
console.log('is.Enum', is.Enum(fakeEnum));


const { IUser } = Type({
    IUser: {
        name: as.string,
        email: as.email,
        password: as.string,
        avatar: (value)=> {
            as.url(value);
            as.minStr({arg: value, value: 3});
            as.maxStr({arg: value, value: 40});
            return value;
        },
        role: (value) => {
            is.false(value!=='admin') && console.error('ROLE ERROR: only one admin required');
            return is.roles(value) ? value: false;
        }
    }
});

const result = as.IUser({
    name: 'name',
    email: 'name@domain.com',
    password: 'qweqweqweqwe',
    avatar: 'https://translate.google.com/',
    role: 'user'
});
console.log(result);
